@@ -1,6 +1,6 @@
 import json
 
-from ..utils import validate_key, validate_limit, validate_page, validate_provider_keys, validate_value
+from ..utils import validate_key, validate_limit, validate_page, validate_provider_keys, validate_value, validate_response
 
 from ..utils import ORDER_BY_VALUES, SORT_BY_VALUES, STAGE_VALUES
 
@@ -56,4 +56,4 @@ class ProfileScoring():
 
         params = {**query_params, **kwargs}
         response = self.client.get('profiles/scoring', params)
-        return response.json()
+        return validate_response(response)
